$body-font-size = 1.4rem
$btn-font-size = 0.9rem
$btn-font-size-icons = 1.1rem
$btn-min-width = 6.5rem
$btn-width = minmax(auto, max-content)
$container-fluid-padding-x = 0

// import color variables
@import './_colors.styl'