.container-fluid {
  width: 100%;
  padding-right: 0;
  padding-left: 0;
  margin-right: auto;
  margin-left: auto;
}
.inline {
  display: inline !important;
}
.inline-flex {
  display: inline-flex !important;
}
.flex {
  display: flex !important;
}
.flex-top {
  flex: 1 0 auto;
}
.flex-bottom {
  flex-shrink: 0;
}
.contain {
  max-height: 85vh;
  max-width: 100vw;
}
.scroll-x {
  overflow-x: scroll;
}
.scroll-y {
  overflow-y: scroll;
}
.fixed-bottom {
  position: fixed !important;
  bottom: 0 !important;
}
.center-x {
  margin-left: auto;
  margin-right: auto;
  left: 50%;
  transform: translateX(-50%);
}
.center-y {
  margin-top: auto;
  margin-bottom: auto;
  top: 50%;
  transform: translateY(50%);
}
.bg-white {
  background-color: #fff !important;
}
.justify-center {
  display: flex;
  justify-content: center !important;
  width: 100% !important;
}
.justify-left {
  display: flex;
  justify-content: left !important;
  width: 100% !important;
}
.justify-right {
  display: flex;
  justify-content: right !important;
  width: 100% !important;
}
.justify-space-between,
.justify {
  display: flex;
  justify-content: space-between !important;
  width: 100% !important;
}
.justify-space-around {
  display: flex;
  justify-content: space-around !important;
  width: 100% !important;
}
.auto-width {
  width: minmax(auto, max-content) !important;
  min-width: auto !important;
  max-width: auto !important;
}
.text-align-left {
  text-align: left !important;
}
.text-align-right {
  text-align: right !important;
}
.text-align-center {
  text-align: center !important;
}
.text-align-justify {
  text-align: justify !important;
}
.p-0 {
  padding: 0rem !important;
}
.px-0 {
  padding-left: 0rem !important;
  padding-right: 0rem !important;
}
.py-0 {
  padding-top: 0rem !important;
  padding-bottom: 0rem !important;
}
.pl-0 {
  padding-left: 0rem !important;
}
.pr-0 {
  padding-right: 0rem !important;
}
.pt-0 {
  padding-top: 0rem !important;
}
.pb-0 {
  padding-bottom: 0rem !important;
}
.m-0 {
  margin: 0rem !important;
}
.mx-0 {
  margin-left: 0rem !important;
  margin-right: 0rem !important;
}
.my-0 {
  margin-top: 0rem !important;
  margin-bottom: 0rem !important;
}
.ml-0 {
  margin-left: 0rem !important;
}
.mr-0 {
  margin-right: 0rem !important;
}
.mt-0 {
  margin-top: 0rem !important;
}
.mb-0 {
  margin-bottom: 0rem !important;
}
.p-1 {
  padding: 1rem !important;
}
.px-1 {
  padding-left: 1rem !important;
  padding-right: 1rem !important;
}
.py-1 {
  padding-top: 1rem !important;
  padding-bottom: 1rem !important;
}
.pl-1 {
  padding-left: 1rem !important;
}
.pr-1 {
  padding-right: 1rem !important;
}
.pt-1 {
  padding-top: 1rem !important;
}
.pb-1 {
  padding-bottom: 1rem !important;
}
.m-1 {
  margin: 1rem !important;
}
.mx-1 {
  margin-left: 1rem !important;
  margin-right: 1rem !important;
}
.my-1 {
  margin-top: 1rem !important;
  margin-bottom: 1rem !important;
}
.ml-1 {
  margin-left: 1rem !important;
}
.mr-1 {
  margin-right: 1rem !important;
}
.mt-1 {
  margin-top: 1rem !important;
}
.mb-1 {
  margin-bottom: 1rem !important;
}
.p-2 {
  padding: 2rem !important;
}
.px-2 {
  padding-left: 2rem !important;
  padding-right: 2rem !important;
}
.py-2 {
  padding-top: 2rem !important;
  padding-bottom: 2rem !important;
}
.pl-2 {
  padding-left: 2rem !important;
}
.pr-2 {
  padding-right: 2rem !important;
}
.pt-2 {
  padding-top: 2rem !important;
}
.pb-2 {
  padding-bottom: 2rem !important;
}
.m-2 {
  margin: 2rem !important;
}
.mx-2 {
  margin-left: 2rem !important;
  margin-right: 2rem !important;
}
.my-2 {
  margin-top: 2rem !important;
  margin-bottom: 2rem !important;
}
.ml-2 {
  margin-left: 2rem !important;
}
.mr-2 {
  margin-right: 2rem !important;
}
.mt-2 {
  margin-top: 2rem !important;
}
.mb-2 {
  margin-bottom: 2rem !important;
}
.p-3 {
  padding: 3rem !important;
}
.px-3 {
  padding-left: 3rem !important;
  padding-right: 3rem !important;
}
.py-3 {
  padding-top: 3rem !important;
  padding-bottom: 3rem !important;
}
.pl-3 {
  padding-left: 3rem !important;
}
.pr-3 {
  padding-right: 3rem !important;
}
.pt-3 {
  padding-top: 3rem !important;
}
.pb-3 {
  padding-bottom: 3rem !important;
}
.m-3 {
  margin: 3rem !important;
}
.mx-3 {
  margin-left: 3rem !important;
  margin-right: 3rem !important;
}
.my-3 {
  margin-top: 3rem !important;
  margin-bottom: 3rem !important;
}
.ml-3 {
  margin-left: 3rem !important;
}
.mr-3 {
  margin-right: 3rem !important;
}
.mt-3 {
  margin-top: 3rem !important;
}
.mb-3 {
  margin-bottom: 3rem !important;
}
.p-4 {
  padding: 4rem !important;
}
.px-4 {
  padding-left: 4rem !important;
  padding-right: 4rem !important;
}
.py-4 {
  padding-top: 4rem !important;
  padding-bottom: 4rem !important;
}
.pl-4 {
  padding-left: 4rem !important;
}
.pr-4 {
  padding-right: 4rem !important;
}
.pt-4 {
  padding-top: 4rem !important;
}
.pb-4 {
  padding-bottom: 4rem !important;
}
.m-4 {
  margin: 4rem !important;
}
.mx-4 {
  margin-left: 4rem !important;
  margin-right: 4rem !important;
}
.my-4 {
  margin-top: 4rem !important;
  margin-bottom: 4rem !important;
}
.ml-4 {
  margin-left: 4rem !important;
}
.mr-4 {
  margin-right: 4rem !important;
}
.mt-4 {
  margin-top: 4rem !important;
}
.mb-4 {
  margin-bottom: 4rem !important;
}
html,
body {
  margin: 0;
  padding: 0;
  height: 100%;
}
html {
  box-sizing: border-box;
}
*,
*:before,
*:after {
  box-sizing: inherit;
}
body {
  color: #222;
  font-size: 1.4rem;
  display: flex;
  flex-direction: column;
}
.container-fluid {
  width: 100%;
  flex: 1 0 auto;
}
.footer {
  flex-shrink: 0;
  width: 100%;
  bottom: 0;
  right: 0;
  left: 0;
  margin-top: auto;
  margin-bottom: 0;
  margin-left: 0;
  margin-right: 0;
  padding: 1rem;
  clear: both;
  background-color: #0cf;
  color: #fff;
  display: flex;
  justify-content: space-between;
}
.footer a {
  color: #fff;
}
.nav {
  display: flex;
  justify-content: space-between;
  width: 100%;
  margin: 0;
  padding: 2rem 1rem;
  background-color: #0cf;
  color: #fff;
  align-items: center;
}
.nav .navbar {
  margin: 0;
  display: inline-flex;
  flex-wrap: wrap;
  justify-content: right;
  align-items: center;
  height: 100%;
}
.nav .navbar .nav-group {
  display: inline-flex;
  margin: 0;
  padding: 0;
}
.nav .navbar .nav-group .nav-item {
  display: inline-flex;
  align-items: center;
  text-align: right;
  border-right: 2px solid #fff;
  color: #f5f5f5;
  box-sizing: border-box;
  padding: 0 1.5rem;
}
.nav .navbar .nav-group .nav-item:hover {
  color: #fff;
}
.nav .navbar .nav-group a.nav-item {
  color: #f5f5f5;
  text-decoration: none;
}
.nav .navbar .nav-group a.nav-item.active {
  color: #fff;
  background-color: rgba(255,255,255,0.3);
}
@media (max-width: 1290px) {
  .nav .navbar {
    height: auto;
  }
  .nav .navbar .nav-item {
    margin-top: 0.5rem;
    margin-bottom: 0.5rem;
  }
  .nav .title h3 {
    font-size: 2.7rem;
  }
}
.page-title-bar {
  padding: 1rem 2rem;
  display: flex;
  justify-content: right;
}
.page-title-bar h2 {
  display: inline-flex;
  margin-bottom: 0;
}
.page-title-bar .side-tool-bar {
  display: inline-flex;
  vertical-align: middle;
  align-self: flex-end;
  align-items: flex-end;
}
.side-tool-bar {
  margin: 0.5rem 0;
  display: flex;
  justify-content: flex-end;
  vertical-align: center;
}
.popup-form tr:last-child td {
  padding: 2rem 1rem;
  text-align: right;
}
.popup-form tr:last-child:hover {
  background-color: transparent;
}
.popup-form tr td {
  padding-left: 1rem;
  padding-right: 1rem;
}
.popup-form tr td:first-child {
  font-weight: bold;
  text-transform: uppercase;
  white-space: nowrap;
  font-size: 1.2rem;
}
.process-form {
  margin-bottom: 0;
}
.process-form input[type="text"] {
  height: 2.5rem;
  padding: 2px 5px;
  margin-right: 0.5rem;
  flex-grow: 1;
}
.process-form button {
  height: 2.5rem;
  border-color: #333;
  opacity: 0.75;
  padding: 0 6px;
  min-width: 4rem;
  width: minmax(auto, max-content);
  flex-shrink: 0;
}
.process-form button i {
  opacity: 0.8;
}
.process-form button:hover {
  border-color: #0e0e0e;
  opacity: 1;
}
.dataTables_wrapper .dataTables_paginate .paginate_button.disabled {
  color: #fcfcfc;
}
.dataTables_wrapper .dataTables_paginate .paginate_button.current {
  background: #eee;
  border: 1px solid transparent;
}
.dataTables_wrapper .dataTables_paginate .paginate_button.current:hover {
  background: #d6d6d6;
  border: 1px solid transparent;
}
.dataTables_wrapper .dataTables_paginate .paginate_button:hover {
  color: #333 !important;
  background: #eff2ff;
  border: 1px solid transparent;
}
.grid-container {
  margin: 2rem 4rem;
  display: flex;
  flex-wrap: wrap;
  justify-content: left;
}
.grid-row {
  background-color: #f5f5f5;
  background-size: 100%;
  display: grid;
  grid-gap: 1rem;
  justify-content: left;
  margin: 1rem 2rem 3rem 2rem;
  padding: 1.5rem;
  overflow-x: scroll;
  overflow-y: hidden;
  width: max-content;
}
.grid-row .header {
  height: 100%;
}
@media (max-width: 960px) {
  .grid-container {
    justify-content: space-between;
  }
  .grid-row {
    margin: 1rem 1rem 3rem 1rem;
  }
}
@media (max-width: 1290px) {
  .grid-container {
    justify-content: space-evenly;
  }
  .grid-row {
    margin: 1rem 2rem 3rem 2rem;
  }
}
.grid-columns-1 {
  grid-template-columns: repeat(1, min-content);
  grid-template-rows: min-content auto;
}
.grid-columns-2 {
  grid-template-columns: repeat(2, min-content);
  grid-template-rows: min-content auto;
}
.grid-columns-3 {
  grid-template-columns: repeat(3, min-content);
  grid-template-rows: min-content auto;
}
.grid-columns-4 {
  grid-template-columns: repeat(4, min-content);
  grid-template-rows: min-content auto;
}
.grid-columns-5 {
  grid-template-columns: repeat(5, min-content);
  grid-template-rows: min-content auto;
}
.grid-columns-6 {
  grid-template-columns: repeat(6, min-content);
  grid-template-rows: min-content auto;
}
.grid-columns-7 {
  grid-template-columns: repeat(7, min-content);
  grid-template-rows: min-content auto;
}
.grid-columns-8 {
  grid-template-columns: repeat(8, min-content);
  grid-template-rows: min-content auto;
}
.grid-columns-9 {
  grid-template-columns: repeat(9, min-content);
  grid-template-rows: min-content auto;
}
.grid-columns-10 {
  grid-template-columns: repeat(10, min-content);
  grid-template-rows: min-content auto;
}
.grid-header {
  background-color: #c1cad6;
}
.grid-header > div,
.grid-info > div {
  padding: 0.85rem;
}
.grid-info {
  height: 100%;
  overflow-y: scroll;
}
.grid-info >div {
  margin: 1rem 0;
  border: 4px solid transparent;
}
.grid-info >div:first-child {
  margin: 0;
}
.grid-info >div:last-child {
  margin-bottom: 0;
}
.tile_component {
  width: 100%;
  display: inline-flex;
  justify-content: space-between;
}
.tile_component .checkbox {
  align-self: right;
}
.button,
button,
input[type="submit"],
input[type="reset"],
input[type="button"] {
  display: inline-block;
  height: 38px;
  padding: 0 30px;
  text-align: center;
  font-weight: 600;
  line-height: 38px;
  letter-spacing: 0.1rem;
  text-transform: uppercase;
  text-decoration: none;
  white-space: nowrap;
  background-color: transparent;
  border-radius: 4px;
  cursor: pointer;
  box-sizing: border-box;
}
.btn-center {
  text-align: center !important;
}
.btn-container {
  max-width: 100%;
  display: grid;
  justify-content: left;
  align-content: space-between;
  grid-template-columns: auto auto;
}
.flex-buttons {
  width: 100%;
  display: flex;
  flex-wrap: wrap;
  justify-content: space-between;
  align-items: flex-start;
}
.action_button {
  font-size: 0.9rem;
  display: inline-block;
  width: minmax(auto, max-content);
  padding: 0px 6px;
  margin: 2px;
  border-color: #333;
  text-transform: uppercase;
  opacity: 0.75;
}
.action_button i {
  padding: 0;
  font-size: 0.9rem;
}
.action_button:hover {
  border-color: #0e0e0e;
  opacity: 1;
}
.action_button.auto-width {
  min-width: 20px;
}
.action_button span {
  margin-left: 4px;
}
.action_button.btn-icons {
  font-size: 1.1rem;
  min-width: 38px;
  text-align: center;
  text-transform: uppercase;
}
.action_button.btn-icons span {
  display: none;
}
.grid-info .action_button {
  text-align: left;
}
.grid-info .action_button span {
  margin: 0;
}
.action_toogle:hover {
  color: #0cf;
}
.clear {
  clear: both;
}
.header-tile-icons {
  display: flex;
  justify-content: flex-start;
  margin: 4px 0.3rem;
}
.header-tile-icons span {
  vertical-align: middle;
  margin: 0 0.25rem 0 0;
}
.header-tile-icons span i {
  margin: 0 0.42rem;
}
.header-tile-icons .state-warning {
  color: #bf360c;
}
ul.process-info {
  margin-bottom: 0;
  margin-right: 1rem;
}
ul.process-info li {
  margin-bottom: 4px;
}
ul.header-tile-info {
  margin-bottom: 0;
}
ul.header-tile-info li {
  display: flex;
  margin-bottom: 4px;
  align-items: center;
  justify-content: left;
}
ul.header-tile-info li i {
  padding: 0;
  top: 4px;
}
div.process_header_tile_off {
  background-color: #d3d3d3;
  height: 100%;
}
div.process_header_tile_on {
  background-color: #dde1e4;
  height: 100%;
}
div.process_info_tile {
  background: #fb8;
  overflow-x: scroll;
  width: 100%;
}
div.table_layout {
  display: block;
  margin-bottom: 0.5rem;
}
div.table_layout_element:first-child {
  margin-right: 8px;
}
div.is_selected_timeperiod {
  border: 4px solid #0288d1;
}
div.is_next_timeperiod {
  border: 4px solid #33691e;
}
div.state_embryo {
  background-color: #d5f5ff;
}
div.state_in_progress {
  background-color: #c3fdb8;
}
div.state_processed {
  background-color: #15c200;
}
div.state_final_run {
  background-color: #adff2f;
}
div.state_skipped {
  background-color: #ff8a65;
}
div.state_skipped .action_button {
  border-color: #0e0e0e;
}
div.state_noop {
  background-color: #ffa;
}
div.state_inconsistent {
  background-color: #d28aff;
}
div.state_inactive {
  background-color: #d3d3d3;
}
@media (max-width: 1290px) {
  .btn-container {
    grid-template-columns: repeat(3, auto);
    justify-content: left;
  }
  .grid-row div .action_button {
    font-size: 1.1rem;
    min-width: 40px;
    display: inline-block;
    padding: 0px 6px;
    text-align: center;
    margin: 2px;
    border-color: #333;
    text-transform: uppercase;
    opacity: 0.75;
  }
  .grid-row div .action_button i {
    font-size: 1.1rem;
  }
  .grid-row div .action_button span {
    display: none;
  }
  .grid-row div.tree_header_tile .action_button {
    font-size: 0.9rem;
  }
  .grid-row div.tree_header_tile .action_button span {
    display: inline;
  }
}
.table-entries {
  border: 1px solid #888 !important;
  margin-bottom: 2rem !important;
}
tr {
  border-top: 1px solid #e8edff;
}
tr:last-child {
  border-bottom: 1px solid #888 !important;
}
tr th {
  padding: 1rem 0;
}
tr:hover {
  background-color: #eff2ff;
}
td,
th {
  padding: 0.5rem 0;
}
td:first-child,
th:first-child {
  padding-left: 1rem !important;
}
td:last-child,
th:last-child {
  padding-right: 1rem !important;
}
form.table-form {
  margin-bottom: 0;
}
.table-entries-header {
  background-color: #d0dafd;
  border-top: 1px solid #888 !important;
}
.table-entries-header:hover {
  background-color: #d0dafd;
}
.table-filter-form {
  background-color: #dde1e4;
  padding: 2rem;
}
.freerun-container {
  max-width: 90%;
  margin: 0 auto;
}
.table-filter-form .table-filter-container {
  display: flex;
  width: 100%;
  justify-content: space-between;
  align-items: center;
  flex-wrap: auto;
}
.table-filter-form .table-filter-container div:nth-child(1) {
  margin-right: 1rem;
}
.table-filter-form .table-filter-container div:nth-child(2) {
  margin-right: 1rem;
}
.table-filter-form .table-filter-container div:nth-child(3) {
  margin-right: 1rem;
}
.table-filter-form .table-filter-container .filter input[type="search"] {
  height: 24px;
  width: auto;
}
.table-filter-form .table-filter-container .refresh-button {
  text-align: right;
}
.dataTables_wrapper {
  margin-bottom: 2rem !important;
}
.dataTables_wrapper .dataTables_filter {
  text-align: left !important;
  float: none !important;
  display: none !important;
}
.dataTables_wrapper .dataTables_filter input[type="search"] {
  height: auto;
}
#dashboard_table_filter {
  display: none !important;
}
tr.state_embryo {
  background-color: #d5f5ff !important;
}
tr.state_in_progress {
  background-color: #c3fdb8 !important;
}
tr.state_processed {
  background-color: #15c200 !important;
}
tr.state_final_run {
  background-color: #adff2f !important;
}
tr.state_skipped {
  background-color: #ff8a65 !important;
}
tr.state_skipped .action_button {
  border-color: #0e0e0e !important;
}
tr.state_noop {
  background-color: #ffa !important;
}
tr.state_inconsistent {
  background-color: #d28aff !important;
}
tr.state_inactive {
  background-color: #d3d3d3 !important;
}
.checkbox {
  display: inline;
}
.checkbox label::before,
.checkbox label::after {
  position: absolute;
  content: "";
  display: inline-block;
}
.switch-label {
  margin: 0 0.5rem;
}
.switch {
  position: relative;
  display: inline-block;
  width: 3rem;
  height: 1.5rem;
}
.switch input {
  opacity: 0;
  width: 0;
  height: 0;
}
.slider {
  position: absolute;
  cursor: pointer;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background-color: #ccc;
  transition: 0.4s;
}
.slider:before {
  position: absolute;
  content: "";
  height: 1rem;
  width: 1rem;
  left: 0.25rem;
  bottom: 0.25rem;
  background-color: #fff;
  transition: 0.2s;
}
.slider.round {
  border-radius: 34px;
}
.slider.round:before {
  border-radius: 50%;
}
input:checked +.slider {
  background-color: #333;
}
input:checked +.slider:before {
  transform: translateX(1.5rem);
}
input:focus +.slider {
  box-shadow: 0 0 1px #333;
}
.context_menu_show {
  position: absolute;
  background-color: #333;
  border: 1px solid #ababaa;
  border-radius: 3px;
  padding: 1px;
  margin: 0;
  list-style: none;
  color: #fff;
  font-weight: 100;
}
.context_menu_show ul {
  margin: 0;
  padding: 0 0 0 5px;
}
.context_menu_show li {
  list-style: none;
  margin: 5px 0;
}
.context_menu_show li a {
  font-weight: 400;
  font-size: 12px;
  text-shadow: 2px 2px #3b3b3b;
  cursor: pointer;
}
.context_menu_show li a:hover {
  color: #aaa;
}
.context_menu_show a {
  border: 0 !important;
  text-decoration: none;
  padding: 0 2em 0 0;
  font-size: 0.85em;
  font-weight: bold;
}
.context_menu_show a:hover {
  text-decoration: underline !important;
}
.context_menu_hide {
  display: none;
}
.container-scroll {
  overflow: scroll;
  height: 90vh !important;
  margin: 1rem 1rem 0 1rem;
  transition: outline 1s;
}
.container-scroll:hover {
  outline: 1px solid #dde1e4;
}
.container-close {
  width: 100%;
  background-color: #fff;
  z-index: 1000;
  bottom: 0;
  left: 0;
  margin: 0;
  padding: 2rem;
  display: flex;
  justify-content: center;
}
.container-close form {
  margin: 0;
}
