$color-1 = #c1cad6
$color-2 = rgba(0, 204, 255, 1)
$color-3 = rgb(89, 216, 248)
$color-4 = #dde1e4
$color-5 = #333
$color-6 = #0e0e0e
$color-7 = #ffbb88
$color-8 = #0288d1
$color-9 = #33691e
$color-10 = #d5f5ff
$color-11 = #000
$color-12 = #c3fdb8
$color-13 = #15c200
$color-14 = #adff2f
$color-15 = #ff8a65
$color-16 = #ffffaa
$color-17 = #d28aff

// colors used in ui.styl
$ui-color-1 = #222
$ui-color-2 = $color-2
$ui-color-3 = rgba(255,255,255,0.3)
$ui-color-4 = #669
$ui-color-5 = #e8edff
$ui-color-6 = #eff2ff
$ui-color-7 = #d0dafd
$ui-color-8 = #ccc
$ui-color-9 = $color-5
$ui-color-10 = #eee
$ui-color-11 = #2196f3
$ui-color-12 = $color-10
$ui-color-14 = $color-12
$ui-color-15 = $color-13
$ui-color-16 = #adff2f
$ui-color-17 = #ff4500
$ui-color-18 = $color-16
$ui-color-19 = $color-17

// context menu colors
$cm-color-1 = $color-5
$cm-color-2 = #ababaa
$cm-color-3 = #fff
$cm-color-4 = #3b3b3b
$cm-color-5 = #aaa

$bg-info = $color-7
$bg-embryo = $color-10
$bg-in-progress = $color-12
$bg-processed = $color-13
$bg-final-run = $color-14
$bg-skipped = $color-7
$bg-off = lightgray
$bg-on = $color-3
$bg-grid-header = $color-1

$border-selected = $color-8
$table-border = #888
$border-next = $color-9
$btn-border = $color-5
$btn-border-hover = $color-6
$warning-icon = red

