.context_menu_show
    position absolute
    background-color $cm-color-1
    border 1px solid $cm-color-2
    border-radius 3px
    padding 1px
    margin 0
    list-style none
    color $cm-color-3
    font-weight 100

    ul
        margin 0
        padding 0 0 0 5px

    li
        list-style none
        margin 5px 0

        a
            font-weight 400
            font-size 12px
            text-shadow 2px 2px $cm-color-4
            cursor pointer

            &:hover
                color $cm-color-5

    a
        border 0 !important
        text-decoration none
        padding 0 2em 0 0
        font-size 0.85em
        font-weight bold

        &:hover
            text-decoration underline !important

.context_menu_hide
    display none
