// Table styles

.table-entries
        border 1px solid $table-border !important
        margin-bottom: 2rem !important
    tr
        border-top 1px solid $ui-color-5
        &:last-child
            border-bottom 1px solid $table-border !important
        th
            padding 1rem 0
        &:hover
            background-color $ui-color-6

    td, th
        padding 0.5rem 0
        &:first-child
            padding-left 1rem !important
        &:last-child
            padding-right 1rem !important

    form.table-form
        margin-bottom 0

.table-entries-header
    background-color $ui-color-7
    border-top 1px solid $table-border !important
    &:hover
        background-color $ui-color-7

.table-filter-form
    background-color $color-4
    padding 2rem


// freerun table
.freerun-container
    max-width 90%
    margin 0 auto

// table filter
.table-filter-form
    .table-filter-container
        display flex
        width 100%
        justify-content space-between
        align-items center
        flex-wrap auto

        for item in 1 2 3
            div:nth-child({item})
                margin-right 1rem

        .filter
            // flex 1 1 auto
            input[type="search"]
                height 24px
                width auto
        .time-window
            // flex 2 1 auto
        .include
            // align-self center
        .refresh-button
            text-align right
            // flex 0 1 auto


// dataTables styles
.dataTables_wrapper
    margin-bottom 2rem !important

    .dataTables_filter
        text-align left !important
        float none !important
        display none !important
        input[type="search"]
            height auto

#dashboard_table_filter
    display none !important


tr
    &.state_embryo
        background-color $color-10 !important

    &.state_in_progress
        background-color $color-12 !important

    &.state_processed
        background-color $color-13 !important

    &.state_final_run
        background-color $color-14 !important

    &.state_skipped
        background-color $color-15 !important

        .action_button
            border-color $color-6 !important

    &.state_noop
        background-color $color-16 !important

    &.state_inconsistent
        background-color $color-17 !important

    &.state_inactive
        background-color lightgray !important
