{% macro trigger_menu(is_freerun) -%}
    <div class="context_menu_hide" id="rmenu">
        <ul>
            <li>
                <a onclick="processBatch({% if is_freerun %}'scheduler/freerun/entry/activate'{% else %}'scheduler/managed/entry/activate'{% endif %})">
                    <i class="fa fa-toggle-on"></i>&nbsp;Activate
                </a>
            </li>
            <li>
                <a onclick="processBatch({% if is_freerun %}'scheduler/freerun/entry/deactivate'{% else %}'scheduler/managed/entry/deactivate'{% endif %})">
                    <i class="fa fa-toggle-off"></i>&nbsp;Deactivate
                </a>
            </li>
        </ul>
    </div>
    <script type="text/javascript" src="{{ url_for('scheduler/static', file='js/context_menu.js') }}"></script>
{%- endmacro %}


{% macro job_menu() -%}
    <div class="context_menu_hide" id="rmenu">
        <ul>
            <li>
                <a onclick="processBatch('scheduler/tree/node/skip')">
                    <i class="fa fa-step-forward"></i>&nbsp;Skip
                </a>
            </li>
            <li>
                <a onclick="processBatch('scheduler/tree/node/reprocess')">
                    <i class="fa fa-repeat"></i>&nbsp;Reprocess
                </a>
            </li>
        </ul>
    </div>
    <script type="text/javascript" src="{{ url_for('scheduler/static', file='js/context_menu.js') }}"></script>
{%- endmacro %}
