// popup window styles

.container-scroll
    overflow scroll
    height 90vh !important
    margin 1rem 1rem 0 1rem
    transition outline 1s
    &:hover
        outline 1px solid $color-4

.container-close
    width 100%
    background-color white
    z-index 1000
    bottom 0
    left 0
    margin 0
    padding 2rem
    display flex
    justify-content center

    form
        margin 0